==> escapework-manager-2.0.0-90a810.tar: resources/views/users/index.blade.php <==
@extends('manager::layouts.master')

@section('content')
    @include('manager::partials.breadcrumb', ['pages' => [trans('manager::users.title')]])

    @include('manager::partials.page-header', [
        'title'    => trans('manager::users.title'),
        'subtitle' => trans('manager::users.subtitle'),
        'link'     => ['route' => route('manager.users.create'), 'label' => trans('manager::users.btn.create'), 'btn-type' => 'primary']
    ])

    @include('manager::partials.messages')

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th>{{ trans('manager::users.index.table.td1') }}</th>
                <th>{{ trans('manager::users.index.table.td2') }}</th>

                @if (config('manager.permissions.on'))
                    <th>{{ trans('manager::users.index.table.td3') }}</th>
                @endif

                <th width="13%"></th>
            </tr>
        </thead>
        <tbody>
            @foreach ($users as $user)
                <tr>
                    <td>{{ $user->name }}</td>
                    <td>{{ $user->email }}</td>

                    @if (config('manager.permissions.on'))
                        <td>{{ $user->role->title }}</td>
                    @endif

                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.users.edit', $user->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> {{ trans('manager::users.btn.edit') }}
                            </a>

                            <a href="{{ route('manager.users.destroy', $user->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> {{ trans('manager::users.btn.delete') }}
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->
@stop

==> escapework-manager-4.2.4-3b065a.tar: resources/views/users/index.blade.php <==
@extends('manager::layouts.master')

@section('content')

    @include('manager::partials.page-header', [
        'title'    => trans('manager::users.title'),
        'subtitle' => trans('manager::users.subtitle'),
        'link'     => ['route' => route('manager.admin-users.create'), 'label' => trans('manager::users.btn.create'), 'btn-type' => 'primary']
    ])

    @include('manager::partials.messages')

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th>{{ trans('manager::users.index.table.td1') }}</th>
                <th>{{ trans('manager::users.index.table.td2') }}</th>

                @if (config('manager.permissions.on'))
                    <th>{{ trans('manager::users.index.table.td3') }}</th>
                @endif

                <th width="13%"></th>
            </tr>
        </thead>
        <tbody>
            @foreach ($users as $user)
                @if (config('manager.permissions.on') === false or Auth::guard('manager')->user()->isAdmin() or $user->role->id > 1)
                <tr>
                    <td>{{ $user->name }}</td>
                    <td>{{ $user->email }}</td>

                    @if (config('manager.permissions.on'))
                        <td>{{ $user->role->title }}</td>
                    @endif

                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.admin-users.edit', $user->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> {{ trans('manager::users.btn.edit') }}
                            </a>

                            <a href="{{ route('manager.admin-users.destroy', $user->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> {{ trans('manager::users.btn.delete') }}
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
                @endif
            @endforeach
        </tbody>
    </table><!-- .table -->
@stop
